Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(770)

Unified Diff: content/browser/frame_host/render_frame_host_impl.cc

Issue 2373273002: Run unload handlers when navigating to about:blank using PlzNavigate. (Closed)
Patch Set: undo incorrect change that broke chrome://crash Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/frame_host/navigator_impl.cc ('k') | content/test/test_render_frame_host.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/frame_host/render_frame_host_impl.cc
diff --git a/content/browser/frame_host/render_frame_host_impl.cc b/content/browser/frame_host/render_frame_host_impl.cc
index c658baf339f335cd10c8c89828beedb2475592e1..795048409664ad081492480563094a175582a80a 100644
--- a/content/browser/frame_host/render_frame_host_impl.cc
+++ b/content/browser/frame_host/render_frame_host_impl.cc
@@ -24,6 +24,7 @@
#include "content/browser/devtools/render_frame_devtools_agent_host.h"
#include "content/browser/download/mhtml_generation_manager.h"
#include "content/browser/frame_host/cross_process_frame_connector.h"
+#include "content/browser/frame_host/debug_urls.h"
#include "content/browser/frame_host/frame_tree.h"
#include "content/browser/frame_host/frame_tree_node.h"
#include "content/browser/frame_host/navigation_entry_impl.h"
@@ -2460,7 +2461,8 @@ void RenderFrameHostImpl::CommitNavigation(
bool is_view_source) {
DCHECK((response && body.get()) ||
common_params.url.SchemeIs(url::kDataScheme) ||
- !ShouldMakeNetworkRequestForURL(common_params.url));
+ !ShouldMakeNetworkRequestForURL(common_params.url) ||
+ IsRendererDebugURL(common_params.url));
UpdatePermissionsForNavigation(common_params, request_params);
// Get back to a clean state, in case we start a new navigation without
@@ -2489,11 +2491,11 @@ void RenderFrameHostImpl::CommitNavigation(
// reading it.
stream_handle_ = std::move(body);
// When navigating to a Javascript url, no commit is expected from the
// RenderFrameHost, nor should the throbber start. The NavigationRequest is
// also not stored in the FrameTreeNode. Therefore do not reset it, as this
// could cancel an existing pending navigation.
- if (!common_params.url.SchemeIs(url::kJavaScriptScheme)) {
+ if (!IsRendererDebugURL(common_params.url)) {
pending_commit_ = true;
is_loading_ = true;
}
@@ -2489,11 +2491,11 @@ void RenderFrameHostImpl::CommitNavigation(
// reading it.
stream_handle_ = std::move(body);
- // When navigating to a Javascript url, no commit is expected from the
+ // When navigating to a debug url, no commit is expected from the
// RenderFrameHost, nor should the throbber start. The NavigationRequest is
// also not stored in the FrameTreeNode. Therefore do not reset it, as this
« no previous file with comments | « content/browser/frame_host/navigator_impl.cc ('k') | content/test/test_render_frame_host.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698